@@ -11,7 +11,7 @@ using namespace QtJson;
 Dailymotion::Dailymotion(QObject *parent) :
     ServicePlugin(parent)
 {
-    m_formatList << "720" << "480" << "380";
+    m_formatList << "stream_h264_hd1080_url" << "stream_h264_hd_url" << "stream_h264_hq_url" << "stream_h264_url";
 }
 
 QRegExp Dailymotion::urlPattern() const {
@@ -24,7 +24,7 @@ bool Dailymotion::urlSupported(const QUrl &url) const {
 
 void Dailymotion::checkUrl(const QUrl &webUrl) {
     QString urlString = webUrl.toString();
-    QRegExp re("\\w{6,6}(_|$)");
+    QRegExp re("\\w{6,7}(_|$)");
     re.indexIn(urlString);
     QString id = re.cap();
     QUrl url;
@@ -94,8 +94,7 @@ void Dailymotion::checkUrlIsValid() {
 
 void Dailymotion::getDownloadUrl(const QUrl &webUrl) {
     emit statusChanged(Connecting);
-    QString id = webUrl.toString().section('/', -1).left(6);
-    //QUrl url("http://www.dailymotion.com/video/" + id);
+    QString id = webUrl.toString().section('/', -1).section('_', 0, 0);
     QUrl url("http://www.dailymotion.com/embed/video/" + id);
     QNetworkRequest request(url);
     QNetworkReply *reply = this->networkAccessManager()->get(request);
@@ -110,73 +109,22 @@ void Dailymotion::parseVideoPage() {
         return;
     }
 
-    /*QString response(QByteArray::fromPercentEncoding(reply->readAll()).replace("\\", ""));
-    QString manifestUrl = response.section("autoURL\":\"", 1, 1).section('"', 0, 0);
-
-    if (manifestUrl.startsWith("http://")) {
-        this->getFormatList(QUrl(manifestUrl));
-    }
-    else {
-        emit error(UnknownError);
-    }*/
-    
     QString response(reply->readAll());
     QVariantMap info = Json::parse(response.section("var info = ", 1, 1).section(";\n", 0, 0)).toMap();
-    QUrl url(info.value("stream_h264_url").toString());
-    
-    if (url.isValid()) {
-        emit downloadRequestReady(QNetworkRequest(url));
-    }
-    else {
-        emit error(UnknownError);
-    }
+    QUrl url;
+    int i = m_formatList.indexOf(QSettings("QDL", "QDL").value("Dailymotion/videoFormat", "stream_h264_url").toString());
 
-    reply->deleteLater();
-}
-
-void Dailymotion::getFormatList(const QUrl &url) {
-    QNetworkRequest request(url);
-    QNetworkReply *reply = this->networkAccessManager()->get(request);
-    this->connect(reply, SIGNAL(finished()), this, SLOT(checkFormatList()));
-}
-
-void Dailymotion::checkFormatList() {
-    QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
-
-    if (!reply) {
-        emit error(NetworkError);
-        return;
-    }
-
-    QString response(reply->readAll());
-    QVariantMap formats = Json::parse(response).toMap();
-    QVariantList formatList = formats.value("alternates").toList();
-    QString preferredFormat = QSettings("QDL", "QDL").value("Dailymotion/videoFormat", "380").toString();
-    QString manifestUrl;
-    int i = m_formatList.indexOf(preferredFormat);
-    int ii = 0;
-
-    while ((manifestUrl.isEmpty()) && (i < m_formatList.size())) {
-        while ((manifestUrl.isEmpty()) && (ii < formatList.size())) {
-            QVariantMap map = formatList.at(ii).toMap();
-            QString name = map.value("name").toString();
-
-            if (name == m_formatList.at(i)) {
-                manifestUrl = map.value("template").toString();
-            }
-
-            ii++;
-        }
-
-        ii = 0;
+    while ((url.isEmpty()) && (i < m_formatList.size())) {
+        url.setUrl(info.value(m_formatList.at(i)).toString());
         i++;
     }
 
-    if (manifestUrl.startsWith("http://")) {
-        this->getVideoUrl(QUrl(manifestUrl));
+    if (url.isEmpty()) {
+        this->setErrorString(info.value("error").toMap().value("message").toString());
+        emit error(UnknownError);
     }
     else {
-        emit error(UnknownError);
+        this->getVideoUrl(url);
     }
 
     reply->deleteLater();
@@ -196,17 +144,13 @@ void Dailymotion::checkVideoUrl() {
         return;
     }
 
-    QString response(reply->readAll());
-    QVariantMap map = Json::parse(response).toMap();
-    QString urlTemplate = map.value("template").toString().remove("frag($fragment$)/");
+    QUrl redirect = reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toUrl();
 
-    if (urlTemplate.isEmpty()) {
-        emit error(UnknownError);
+    if (redirect.isEmpty()) {
+        emit downloadRequestReady(QNetworkRequest(reply->request().url()));
     }
     else {
-        QString host = reply->request().url().host();
-        QUrl url(QString("http://%1%2").arg(host).arg(urlTemplate));
-        emit downloadRequestReady(QNetworkRequest(url));
+        emit downloadRequestReady(QNetworkRequest(redirect));
     }
 
     reply->deleteLater();
