@@ -22,20 +22,21 @@ public:
     void getDownloadUrl(const QUrl &webUrl);
     inline bool loginSupported() const { return false; }
     inline bool recaptchaRequired() const { return false; }
+    inline QString errorString() const { return m_errorString; }
 
 private:
     void checkPlaylistVideoUrls(const QUrl &url);
-    void getFormatList(const QUrl &url);
     void getVideoUrl(const QUrl &url);
+    inline void setErrorString(const QString &errorString) { m_errorString = errorString; }
 
 private slots:
     void checkUrlIsValid();
     void parseVideoPage();
-    void checkFormatList();
     void checkVideoUrl();
 
 private:
     QStringList m_formatList;
+    QString m_errorString;
 };
 
 #endif // DAILYMOTION_H
